<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// C
	'compresseur_description' => 'Compressione di CSS e javascript 
nell’intestazione delle pagine html di <code>ecrire/</code> e/o del sito pubblico pubblico.',
	'compresseur_slogan' => 'Compressione di CSS e javascript',
];
